<?php
/** Zazaki (Zazaki)
 *
 * @ingroup Language
 * @file
 *
 * @author Belekvor
 * @author Mirzali
 */

$messages = array(
# User preference toggles
'tog-underline'               => 'Bınê gırêyan de xete bıance:',
'tog-highlightbroken'         => 'Gırêyanê vengan {a href="" class="new"}wına{/a} (alternative: wına{a 
href="" class="internal"}?{/a}) bımocne.',
'tog-justify'                 => 'Nuşte dı kıştan ser bıazne',
'tog-hideminor'               => 'Vurnayışanê şenıkan pela „vurnayışê peyêni“ de bınımne',
'tog-extendwatchlist'         => 'Lista seyr-kerdışia herakerdiye',
'tog-usenewrc'                => "Lista vurnayışanê peyênana herakerdiye (''JavaScript'' lazımo)",
'tog-numberheadings'          => 'Sernuşteyan be xo numre cışane',
'tog-showtoolbar'             => 'Goceganê hacetanê vurnayışi bımocne (JavaScript lazımo)',
'tog-editondblclick'          => 'Pê dı rey tıknayış pele sero bıxebetiye (JavaScript lazımo)',
'tog-editsection'             => 'Gırêyanê [bıvurne] sera qısımê vurnayışi feal ke',
'tog-editsectiononrightclick' => 'Sernuştey qısıman sero be gocega raşte tıknayene bıvurne (JavaScript lazımo)',
'tog-showtoc'                 => 'Tabloyê tedeesteyan bımocne (de pelanê be hirê sernuşteyan ra vêşêri de)',
'tog-rememberpassword'        => 'Parola mı bia xo viri',
'tog-editwidth'               => 'Verıniya pela cıdayışê nuştey tam bıaso',
'tog-watchcreations'          => 'Pelê ke mı afernayê, lista mına seyr-kerdışi ke',
'tog-watchdefault'            => 'Pelê ke mı vurnayê, lista mına seyr-kerdışi ke',
'tog-watchmoves'              => 'Pelê ke mı kırışnayê, lista mına seyr-kerdışi ke',
'tog-watchdeletion'           => 'Pelê ke mı esterıtê, lista mına seyr-kerdışi ke',
'tog-minordefault'            => 'Vurnayışanê xo pêrune ‘vurnayışo qıckek’ nışan bıde',
'tog-previewontop'            => 'Verqayti pela nuştışi ser de bımocne',
'tog-previewonfirst'          => 'Vurnayışo verên de verqayti tım bımocne',
'tog-nocache'                 => 'Pelan mia xo viri',
'tog-enotifwatchlistpages'    => 'Pela ke ez seyr kenan eke vurnayê mı rê e-mail bırışe',
'tog-enotifusertalkpages'     => 'Pela mına werênayışi ke vurnayê, mı rê e-mail bırışe',
'tog-enotifminoredits'        => 'Vurnayışanê qıckekan de ki mı rê e-mail bırışe',
'tog-enotifrevealaddr'        => 'E-mailadresa mı emailanê xeberan de bımocne',
'tog-shownumberswatching'     => 'Amarê karberanê seyrkerdoğan bımocne',
'tog-fancysig'                => 'İmza xame (bê gırêo otomatik be pela karberan ser)',
'tog-externaleditor'          => 'Editorê teberi standard bıxebetne (tenya seba ekspertano, komputerê şıma de ayarê xususiy lazımê)',
'tog-externaldiff'            => 'Têverşanayışan pê programê teberi vıraze (tenya seba ekspertano, komputerê şıma de ayarê xususiy lazımê)',
'tog-showjumplinks'           => 'Gırey "şo"y feal ke',
'tog-uselivepreview'          => 'Verqayto cınde bıxebetne (JavaScript lazımo) (hewna cerrebnayış dero)',
'tog-forceeditsummary'        => 'Mı ke xulasa kerde cı vira, hay be mı ser de',
'tog-watchlisthideown'        => 'Vurnayışanê mı lista mına seyr-kerdışi de bınımne',
'tog-watchlisthidebots'       => 'Vurnayışanê boti lista mına seyr-kerdışi de bınımne',
'tog-watchlisthideminor'      => 'Vurnayışanê qıckekan lista mına seyr-kerdışi de bınımne',
'tog-watchlisthideliu'        => 'Lista seyrkerdışi ra vurnayışanê karberanê cıkewteyan bınımne',
'tog-watchlisthideanons'      => 'Lista seyrkerdışi ra vurnayışanê karberanê anoniman bınımne',
'tog-ccmeonemails'            => 'E-mailanê ke ez karberanê binan rê rışenan, mı rê kopya inan bırışe',
'tog-diffonly'                => 'Qıyasê verziyonan de tek ferqan bımocne, perra butıne nê',
'tog-showhiddencats'          => 'Kategoriyanê dızdine bımocne',
'tog-norollbackdiff'          => 'Peyserardene ra dıme ferqi caverde',

'underline-always'  => 'Tım',
'underline-never'   => 'Qet',
'underline-default' => 'Qerar cıgeyraoği dest dero',

# Dates
'sunday'        => 'Kırê',
'monday'        => 'Dışeme',
'tuesday'       => 'Sêşeme',
'wednesday'     => 'Çarşeme',
'thursday'      => 'Phancşeme',
'friday'        => 'Êne',
'saturday'      => 'Şeme',
'sun'           => 'Kır',
'mon'           => 'Dşm',
'tue'           => 'Sşm',
'wed'           => 'Çrş',
'thu'           => 'Pşm',
'fri'           => 'Êne',
'sat'           => 'Şem',
'january'       => 'Çele',
'february'      => 'Şıbate',
'march'         => 'Adar',
'april'         => 'Nisane',
'may_long'      => 'Gulane',
'june'          => 'Heziran',
'july'          => 'Temmuz',
'august'        => 'Tebaxe',
'september'     => 'Keşkelun',
'october'       => 'Tışrino Verên',
'november'      => 'Tışrino Peyên',
'december'      => 'Kanun',
'january-gen'   => 'Çeley',
'february-gen'  => 'Şıbate',
'march-gen'     => 'Adari',
'april-gen'     => 'Nisane',
'may-gen'       => 'Gulane',
'june-gen'      => 'Hezirani',
'july-gen'      => 'Temmuzi',
'august-gen'    => 'Tebaxe',
'september-gen' => 'Keşkeluni',
'october-gen'   => 'Tışrinê Verêni',
'november-gen'  => 'Tışrinê Peyêni',
'december-gen'  => 'Kanuni',
'jan'           => 'Çel',
'feb'           => 'Şbt',
'mar'           => 'Adr',
'apr'           => 'Nsn',
'may'           => 'Gln',
'jun'           => 'Hzr',
'jul'           => 'Tmz',
'aug'           => 'Tbx',
'sep'           => 'Kşk',
'oct'           => 'Tşv',
'nov'           => 'Tşp',
'dec'           => 'Kan',

# Categories related messages
'pagecategories'           => '{{PLURAL:$1|Kategoriye|Kategoriy}}',
'category_header'          => 'Pelê ke kategoriya "$1" derê',
'subcategories'            => 'Kategoriyê bınêni',
'category-media-header'    => 'Medyawa ke kategoriya "$1" (-i/-an) dera',
'category-empty'           => "''Ena kategoriye de hewna qet nuştey ya ki medyay çıniyê.''",
'hidden-categories'        => '{{PLURAL:$1|Kategoriya nımıtiye|Kategoriyê nımıtey}}',
'hidden-category-category' => 'Kategoriyê nımıtey', # Name of the category where hidden categories will be listed

'mainpagetext'      => "<big>'''MediaWiki vıst ra ser, vıraziya.'''</big>",
'mainpagedocfooter' => "Gurenayış u ayarkerdena Wiki-Software rê yardım etıya de vênenay: [http://meta.wikimedia.org/wiki/Help:Contents User's Guide]

== Yardımê Sıftekerdene ==

* [http://www.mediawiki.org/wiki/Manual:Configuration_settings Configuration settings list]
* [http://www.mediawiki.org/wiki/Manual:FAQ MediaWiki FAQ]
* [https://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki release mailing list]",

'about'          => 'Heqa',
'article'        => 'Pela tedeesteyan',
'newwindow'      => '(zerrey pençereyê de newey de beno a)',
'cancel'         => 'Bıtexelne',
'qbfind'         => 'Bıvêne',
'qbbrowse'       => 'Çım ra bıviyarne',
'qbedit'         => 'Bıvurne',
'qbpageoptions'  => 'Ena perre',
'qbpageinfo'     => 'Melumatê perre',
'qbmyoptions'    => 'Perrê mı',
'qbspecialpages' => 'Perrê xasi',
'moredotdotdot'  => 'Vêşêri (zêdêri)...',
'mypage'         => 'Perra mı',
'mytalk'         => 'Perra mına werênayışi',
'anontalk'       => 'Perra werênayışê nê IPy',
'navigation'     => 'pusula',
'and'            => '&#32;u',

'errorpagetitle'    => 'Xeta',
'returnto'          => 'Peyser şo $1.',
'tagline'           => '{{SITENAME}} ra',
'help'              => 'Pheşti',
'search'            => 'cıgeyrayış',
'searchbutton'      => 'Cıgeyre',
'go'                => 'Şo',
'searcharticle'     => 'Şo',
'history'           => 'tarix',
'history_short'     => 'tarix',
'updatedmarker'     => 'cıkewtena mına peyêne ra dıme biyo rocane/biya rocaniye/biyê rocaniy',
'info_short'        => 'Melumat',
'printableversion'  => 'Asayışê çapkerdene',
'permalink'         => 'Gırey be halê peyêni',
'print'             => 'çap ke',
'edit'              => 'bıvurne',
'editthispage'      => 'Ena pele bıvurne',
'create-this-page'  => 'Na pele bınuse',
'delete'            => 'bıestere',
'deletethispage'    => 'Ena pele bıestere',
'undelete_short'    => '{{PLURAL:$1|yew vurnayışi|$1 vurnayışan}} meestere',
'protect'           => 'kılit ke',
'protect_change'    => 'bıvurne',
'protectthispage'   => 'Ena perre kılit ke',
'unprotect'         => 'ake',
'unprotectthispage' => 'Ena perre ake',
'newpage'           => 'Perra newiye',
'talkpage'          => 'Ena perre sero werêne',
'talkpagelinktext'  => 'Werênayış',
'specialpage'       => 'Perra xase',
'personaltools'     => 'Hacetê şexsi',
'articlepage'       => 'nuşte',
'talk'              => 'werênayış',
'views'             => 'Asayışi',
'toolbox'           => 'haceti',
'userpage'          => 'Pela Karberi',
'projectpage'       => 'Perra projey bıvêne',
'imagepage'         => 'Perra medya bımocne',
'mediawikipage'     => 'Perra mesaji bımocne',
'templatepage'      => 'Perra şabloni bımocne',
'viewhelppage'      => 'Perra pheşti bıvêne',
'categorypage'      => 'Perra kategoriye bıvêne',
'viewtalkpage'      => 'Perra werênayışi bıvêne',
'otherlanguages'    => 'zıwananê binan de',
'redirectedfrom'    => '($1 ra neqıl bi)',
'lastmodifiedat'    => 'Ena pele tewr peyên roca $2, $1 de biya rocaniye.', # $1 date, $2 time
'viewcount'         => 'Ena perre {{PLURAL:$1|rae|$1 rey}} vêniya.',
'protectedpage'     => 'Perra kılitkerdiye',
'jumpto'            => 'Şo be:',
'jumptonavigation'  => 'şiyayış',
'jumptosearch'      => 'cıgeyre',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Heqa {{SITENAME}} de',
'aboutpage'            => 'Project:Heqa',
'copyright'            => 'Nuştey bınê Lisansê $1 de vêrenê.',
'copyrightpagename'    => 'Heqa telifê {{SITENAME}}',
'copyrightpage'        => '{{ns:project}}:Heqê telifi',
'currentevents'        => 'Textey cerrebi',
'currentevents-url'    => 'Project:Textey cerrebi',
'disclaimers'          => 'Reddê mesuliyeti',
'disclaimerpage'       => 'Project:Reddê mesuliyetê bıngey',
'edithelp'             => 'Pheştdarina vurnayışi',
'edithelppage'         => 'Help:Perre çıtewr vurniyena',
'helppage'             => 'Help:Tedeestey',
'mainpage'             => 'Pela Seri',
'mainpage-description' => 'Pela Seri',
'portal'               => 'Portalê cemaeti',
'portal-url'           => 'Project:Portalê Cemaeti',
'privacy'              => 'Maddey dızdine',
'privacypage'          => 'Project:Maddey dızdine',

'badaccess' => 'Xeta mısadey',

'ok'                      => 'Temam',
'retrievedfrom'           => '"$1" ra ard',
'youhavenewmessages'      => 'To rê estê $1 ($2).',
'newmessageslink'         => 'mesajê newey',
'newmessagesdifflink'     => 'vurnayişo peyên',
'youhavenewmessagesmulti' => 'To rê $1 de mesajê newey estê',
'editsection'             => 'bıvurne',
'editsection-brackets'    => '[$1]',
'editold'                 => 'bıvurne',
'viewsourceold'           => 'çımey bıvêne',
'editlink'                => 'bıvurne',
'viewsourcelink'          => 'çımey bıvêne',
'editsectionhint'         => 'Qısımê vurnayışi: $1',
'toc'                     => 'Tedeestey',
'showtoc'                 => 'bımocne',
'hidetoc'                 => 'bınımne',
'thisisdeleted'           => 'Bıvêne ya ki restore ke $1?',
'viewdeleted'             => '$1 bıvêne?',
'restorelink'             => '{{PLURAL:$1|yew vurnayışo esterıte (pakbiyae)|$1 vurnayışê esterıtey (pakbiyaey)}}',
'feedlinks'               => 'Weyikerdış:',
'feed-invalid'            => 'Tipê weyikerdışê beğşê nêvêrdey.',
'site-rss-feed'           => 'Weyi-kerdışê $1 RSSi',
'site-atom-feed'          => 'Weyi-kerdışê $1 Atomi',
'red-link-title'          => '$1 (pele çina)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'nuşte',
'nstab-user'      => 'Pela Karberi',
'nstab-media'     => 'Pela Medya',
'nstab-special'   => 'Pela xase',
'nstab-project'   => 'Pela Procey',
'nstab-image'     => 'Dosya',
'nstab-mediawiki' => 'Mesaj',
'nstab-template'  => 'Şablon',
'nstab-help'      => 'Pela pheşti',
'nstab-category'  => 'Kategoriye',

# Main script and global functions
'nosuchaction'      => 'Faliyeto henên/otir çino',
'nosuchspecialpage' => 'Pela xasa henêne/otir çina',
'nospecialpagetext' => "<big>'''To yew pela xasa nêvêrdiye waşte.'''</big>

Seba /qandê lista pelanê xasanê vêrdeyan kerem ke: [[Special:SpecialPages|{{int:specialpages}}]].",

# General errors
'error'               => 'Ğelet',
'badtitle'            => 'Sernameya xırabe',
'viewsource'          => 'Çımey bıvêne',
'viewsourcefor'       => 'Seba / qandê $1',
'viewsourcetext'      => 'To şikinay çımey na pele bıvêne u kopya kerê:',
'ns-specialprotected' => 'Pelê xasi nênê vurnayış.',

# Login and logout pages
'logouttitle'               => 'Veciyaena karberi',
'loginpagetitle'            => 'Cıkewtena karberi',
'yourname'                  => 'Namey karberi',
'yourpassword'              => 'Parola',
'yourpasswordagain'         => 'Parola reyna bınusne',
'remembermypassword'        => 'Na/In komputer de mı biya xo viri',
'login'                     => 'Cıkewe',
'nav-login-createaccount'   => 'Cıkewe / hesab vıraze',
'loginprompt'               => "Seba ke mumkın bo şıma bıkewê pela {{SITENAME}}, programê internetê şıma de ''cookies''i gereke aktifi bê.",
'userlogin'                 => 'Cıkewe ya ki hesab vıraze',
'logout'                    => 'Veciye',
'userlogout'                => 'Veciye',
'nologin'                   => 'Hesabê şıma çıniyo? $1.',
'nologinlink'               => 'Yewê akerê',
'createaccount'             => 'hesab vıraze',
'gotaccount'                => 'Hesabê şıma esto? $1.',
'gotaccountlink'            => 'Cıkewe',
'createaccountmail'         => 'Mı rê e-mail sera parola bırışe',
'youremail'                 => 'E-Mail (mecbur niyo) *:',
'username'                  => 'Namey karberi:',
'uid'                       => 'Namey karberi:',
'yourrealname'              => 'Namo raştıkên:',
'yourlanguage'              => 'Zıwan:',
'yournick'                  => 'imza:',
'prefs-help-realname'       => 'Nameo raşt waştena şıma rê mendo.
If you choose to provide it, this will be used for giving you attribution for your work.',
'prefs-help-email-required' => 'E-mail adrese mecburiya.',
'wrongpassword'             => 'Parola ğeleta. Rêna / fına bıcerrebne .',
'passwordtooshort'          => 'Parola to nêvêrena ya ki zaf kılma.
It must have at least $1 characters and be different from your username.',
'mailmypassword'            => 'E-mail sera parola newiye bırışe',
'accountcreated'            => 'Hesab vıraciya',
'loginlanguagelabel'        => 'Zıwan: $1',

# Password reset dialog
'oldpassword' => 'Parola kıhane:',
'newpassword' => 'Parola newiye:',
'retypenew'   => 'Parola newiye tekrar ke:',

# Edit pages
'summary'      => 'Xulasa:',
'savearticle'  => 'Ena pele qeyd ke',
'preview'      => 'Verqayt',
'showpreview'  => 'Verqayti bımocne',
'showdiff'     => 'Vurnayışi bımocne',
'loginreqlink' => 'Cıkewe',
'newarticle'   => '(Newe)',

# History pages
'revisionasof'     => 'Verziyonê roca $1ine',
'previousrevision' => '← Rewşa kıhanêre',
'cur'              => 'ferq',
'last'             => 'pey',

# Revision deletion
'rev-delundel' => 'bımocne/bınımne',

# Diffs
'lineno'   => 'Rêza $1i:',
'editundo' => 'peyser biya',

# Search results
'searchhelp-url'     => 'Help:Tedeestey',
'search-result-size' => '$1 ({{PLURAL:$2|1 çekuye|$2 çekuy}})',
'powersearch'        => 'Cıgeyrayışo hera',
'powersearch-legend' => 'Cıgeyrayışo hera',
'powersearch-ns'     => 'Cayanê nameyan de cıgeyrayış:',
'powersearch-redir'  => 'Raçarnayeyan lista ke',
'powersearch-field'  => 'Cıgeyre',
'search-external'    => 'Cıgeyrayışê teberi',

# Preferences page
'mypreferences'   => 'tercihê mı',
'qbsettings-none' => 'çino',
'skin-preview'    => 'Verqayt',
'prefs-personal'  => 'Pela karberi',
'prefs-rc'        => 'Vurnayışê peyêni',
'prefs-watchlist' => 'Lista seyr-kerdışi',
'saveprefs'       => 'Qeyd ke',
'timezonelegend'  => 'Warey saete',
'files'           => 'Dosyey',

# User rights log
'rightsnone' => '(çino)',

# Recent changes
'recentchanges'   => 'Vurnayışê peyêni',
'diff'            => 'ferq',
'hist'            => 'ver',
'hide'            => 'Bınımne',
'show'            => 'Bımocne',
'minoreditletter' => 'q',
'newpageletter'   => 'N',
'boteditletter'   => 'b',
'sectionlink'     => '→',

# Recent changes linked
'recentchangeslinked' => 'Ney sero vurnayışi',

# Upload
'upload'     => 'Dosya bar ke',
'uploadbtn'  => 'Dosya bar ke',
'filename'   => 'Namey Dosya',
'filesource' => 'Çımey:',
'savefile'   => 'Dosya qeyd ke',

# Special:ListFiles
'imgfile'        => 'dosya',
'listfiles'      => 'Lista Dosya',
'listfiles_date' => 'Tarix',
'listfiles_user' => 'Karber',

# File description page
'filehist'          => 'Tarixê dosya',
'filehist-datetime' => 'Tarix/Zeman',
'filehist-user'     => 'Karber',
'imagelinks'        => 'Gıreyê dosya',
'noimage-linktext'  => 'Bar ke',

# File deletion
'filedelete'        => '$1 bıestere',
'filedelete-legend' => 'Dosya bıestere',
'filedelete-submit' => 'Bıestere',

# MIME search
'download' => 'bar ke',

# Random page
'randompage' => 'Kamci pele ke raşt amê',

'brokenredirects-edit'   => '(bıvurne)',
'brokenredirects-delete' => '(bıestere)',

'withoutinterwiki-submit' => 'Bımocne',

# Miscellaneous special pages
'nbytes'            => '$1 {{PLURAL:$1|bayt|bayti}}',
'ncategories'       => '$1 {{PLURAL:$1|Kategoriye|Kategoriy}}',
'shortpages'        => 'Pelê kılmi',
'longpages'         => 'Pelê dergi',
'listusers'         => 'Lista karberan',
'newpages'          => 'Pelê newey',
'newpages-username' => 'Namey Karberi:',
'ancientpages'      => 'Pelê kıhanêri',
'move'              => 'bere',

# Book sources
'booksources-go' => 'Şo',

# Special:Log
'specialloguserlabel' => 'Karber:',

# Special:AllPages
'alphaindexline' => '$1 ra $2ine',
'nextpage'       => 'Pela peyêne ($1)',
'prevpage'       => 'Pela verêne ($1)',
'allpagessubmit' => 'Şo',

# Special:Categories
'categories' => 'Kategoriy',

# Special:ListUsers
'listusers-submit' => 'Bımocne',

# Watchlist
'watchlist'   => 'lista mına seyr-kerdışi',
'mywatchlist' => 'Lista mına seyr-kerdışi',
'watch'       => 'bıgê seyr-kerdış',
'unwatch'     => 'Endi seyr meke',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Seyr ke...',
'unwatching' => 'Seyr meke...',

# Delete
'deletepage'            => 'Pele bıestere',
'deletereasonotherlist' => 'Sebebo bin',

# Rollback
'rollbacklink' => 'peyser bia',

# Restrictions (nouns)
'restriction-edit' => 'Bıvurne',

# Namespace form on various pages
'blanknamespace' => '(Ser)',

# Contributions
'mycontris' => 'iştırakê mı',

'sp-contributions-newbies'  => 'Tenya iştıraqanê karberanê neweyan bımocne',
'sp-contributions-username' => 'Adresa IPy ya ki namey karberi:',

# What links here
'whatlinkshere'       => 'Gırey be pele',
'whatlinkshere-page'  => 'Pele:',
'whatlinkshere-links' => '← gırey',

# Block/unblock
'blocklink'    => 'kılit ke',
'unblocklink'  => 'ake',
'contribslink' => 'iştıraki',
'autoblocker'  => 'Şıma otomatikmen kılit biy, çıke adresa şımawa \'\'IP\'\'y terefê "[[User:$1|$1]]" gureniyena. 
Sebebê kılit-biyayışê $1\'i: "$2"o',
'blocklogpage' => 'Protokolê kıliti',

# Move page
'1movedto2'  => '[[$1]] berd be [[$2]]',
'movereason' => 'Sebeb:',

# Thumbnails
'thumbnail-more' => 'Gırd ke',

# Tooltip help for the actions
'tooltip-pt-userpage'      => 'Pela şımawa karberi',
'tooltip-pt-mytalk'        => 'Pela şımawa werênayışi',
'tooltip-pt-login'         => 'Seba cıkotışi şıma rê dewato, labelê no zeruri niyo.',
'tooltip-pt-logout'        => 'Veciye',
'tooltip-ca-talk'          => 'Pela tedeesteyan sero werênayış',
'tooltip-ca-edit'          => 'Tı eşkenay na pele bıvurnê.
Kerem ke, qeyd-kerdış ra ver gozega verqayti bıxebıtne.',
'tooltip-search'           => 'Zerrey {{SITENAME}} de cıgeyre',
'tooltip-search-go'        => 'Ebe nê namey şo yew pele, eke esta',
'tooltip-search-fulltext'  => 'Seba nê meqaley pelan saye ke',
'tooltip-n-mainpage'       => 'Pela Seri bıvêne',
'tooltip-n-portal'         => 'Heqa projey de, tı çı eşkenay bıkerê, koti çiy vêniyenê',
'tooltip-n-currentevents'  => 'Vurnayışanê peyênan de melumatê pey bıvêne',
'tooltip-n-recentchanges'  => 'Wiki de lista vurnayışanê peyênan.',
'tooltip-n-randompage'     => 'Kamci pele ke raşt amey bar ke',
'tooltip-n-help'           => 'Cayê doş-kerdışi.',
'tooltip-t-whatlinkshere'  => 'Lista pelanê wikiya pêroina ke tiya gırê bena',
'tooltip-t-upload'         => 'Dosya bar ke',
'tooltip-t-specialpages'   => 'Lista pelanê xasanê pêroinan bımocne',
'tooltip-ca-nstab-main'    => 'Pela tedeesteyan bıvêne',
'tooltip-ca-nstab-special' => 'Na yew pelê da xususiya, şıma nêşenê nae bıvurnê',

# Attribution
'lastmodifiedatby' => 'Ena pele tewr peyên roca $2, $1 by $3. de biya rocaniye', # $1 date, $2 time, $3 user

# Special:NewFiles
'ilsubmit' => 'Cıgeyre',

# Bad image list
'bad_image_list' => 'Şeklo umumi wınayo:

Tenya çiyo ke beno lista (rezê ke be * dest kenê cı) çıman ver de vêniyeno.
Yew rêze de gırêyo sıfteyın gani gırêyo de dosya xırabıne bo.
Na rêze de her gırêyo bin zey istisna vêniyeno, yanê pelê ke dosya beno ke sero rêzbiyaye asena.',

'exif-gaincontrol-0' => 'çino',

# Special:FilePath
'filepath-page' => 'Dosya:',

# Special:SpecialPages
'specialpages' => 'Pelê xasi',

);
